import { DependencyContainer } from "./DependencyContainer";
import { LocalStorageService } from "./Services/LocalStorageService";
import { ExalusConnectionService } from './Services/ExalusConnectionService';
import { WebApiCacheService } from "./Services/WebApi/WebApiCacheService";
import { UsersService } from "./Services/Users/UsersService";
import { DevicesService } from "./Services/Devices/DevicesService";
import { SessionService } from "./Services/Session/SessionService";
import { ControllerConfigurationService } from "./Services/Controller/ControllerConfigurationService";
import { initializeLinq } from "linq-to-typescript";
initializeLinq();
export class Api {
    static Init() {
        if (DependencyContainer.IsInitialized)
            return;
        let dep = DependencyContainer.Instance;
        try {
            dep.RegisterService(new LocalStorageService());
            dep.RegisterService(new WebApiCacheService());
            dep.RegisterService(new SessionService());
            dep.RegisterService(new ExalusConnectionService());
            dep.RegisterService(new ControllerConfigurationService());
            dep.RegisterService(new UsersService());
            dep.RegisterService(new DevicesService());
        }
        catch (ex) {
            console.error(ex);
        }
    }
    static GetAsync(classType, cancelationToken) {
        return DependencyContainer.Instance.GetServiceAsync(classType, cancelationToken);
    }
    static GetWithTimeoutAsync(classType, timeout) {
        return DependencyContainer.Instance.GetServiceWithTimeoutAsync(classType, timeout);
    }
    static Get(classType) {
        return DependencyContainer.Instance.GetService(classType);
    }
    static SleepForAsync(miliseconds) {
        return new Promise(resolve => setTimeout(resolve, miliseconds));
    }
}
Api.Version = 1.0;
//# sourceMappingURL=Api.js.map