import { nameof } from 'ts-simple-nameof';
import { TypedEvent } from './TypedEvent';
import { LoggerService } from './Services/Logging/LoggerService';
export class DependencyContainer {
    constructor() {
        this._services = {};
        this._serviceRegistrationEvent = new TypedEvent();
    }
    static get Instance() {
        if (DependencyContainer._instance != null)
            return DependencyContainer._instance;
        DependencyContainer._instance = new DependencyContainer();
        this.Log = new LoggerService();
        this.Log.Warning("Initializing DependencyContainer");
        DependencyContainer._instance.RegisterService(this.Log);
        this.IsInitialized = true;
        return DependencyContainer._instance;
    }
    RegisterService(service) {
        var _a;
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, `Registering new service: ${service.GetServiceName()}`);
        this._services[service.GetServiceName()] = service;
    }
    GetService(classType) {
        var _a;
        let name = nameof(classType);
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, `Getting service [${name}] by GetService<T>()`);
        return this._services[name];
    }
    GetServiceAsync(classType, token) {
        var _a, _b;
        let name = nameof(classType);
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, `Waiting for service availability [${name}] by GetServiceAsync<T>()`);
        if (this._services.hasOwnProperty(name)) {
            (_b = DependencyContainer.Log) === null || _b === void 0 ? void 0 : _b.Debug(DependencyContainer, `Got service [${name}] by GetServiceAsync<T>()`);
            return Promise.resolve(this._services[name]);
        }
        return new Promise((resolve, reject) => {
            var sub = (service) => {
                var _a;
                if ((service === null || service === void 0 ? void 0 : service.GetServiceName()) === name) {
                    (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, `Got service [${name}] by GetServiceAsync<T>()`);
                    this._serviceRegistrationEvent.Unsubscribe(sub);
                    resolve(service);
                }
            };
            var onCancel = () => {
                var _a;
                this._serviceRegistrationEvent.Unsubscribe(sub);
                token === null || token === void 0 ? void 0 : token.CancellationEvent.Unsubscribe(onCancel);
                (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, `Cancelled service [${name}] retrieval by GetServiceAsync<T>()`);
                reject(new Error("Operation cancelled!"));
            };
            token === null || token === void 0 ? void 0 : token.CancellationEvent.Subscribe(onCancel);
            this._serviceRegistrationEvent.Subscribe(sub);
        });
    }
    GetServiceWithTimeoutAsync(classType, timeout) {
        var _a, _b;
        let name = nameof(classType);
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, `Waiting for service[${name}] availability by GetServiceWithTimeoutAsync<T>()`);
        if (this._services.hasOwnProperty(name)) {
            (_b = DependencyContainer.Log) === null || _b === void 0 ? void 0 : _b.Debug(DependencyContainer, `Got service [${name}] by GetServiceWithTimeoutAsync<T>()`);
            return Promise.resolve(this._services[name]);
        }
        return new Promise((resolve, reject) => {
            let timeoutId = 0;
            let sub = (service) => {
                var _a;
                if ((service === null || service === void 0 ? void 0 : service.GetClassName()) === name) {
                    (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, `Got service [${name}] by GetServiceWithTimeoutAsync<T>()`);
                    window.clearTimeout(timeoutId);
                    this._serviceRegistrationEvent.Unsubscribe(sub);
                    resolve(service);
                }
            };
            let onTimeout = () => {
                var _a;
                window.clearTimeout(timeoutId);
                this._serviceRegistrationEvent.Unsubscribe(sub);
                (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Error(DependencyContainer, `Failed to get service [${name}] in time by GetServiceWithTimeoutAsync<T>()`);
                reject(new Error("Operation cancelled!"));
            };
            timeoutId = window.setTimeout(onTimeout, timeout);
            this._serviceRegistrationEvent.Subscribe(sub);
        });
    }
}
DependencyContainer.IsInitialized = false;
//# sourceMappingURL=DependencyContainer.js.map