import { DeviceResponseType } from "./IDevice";
import { nameof } from 'ts-simple-nameof';
export class DeviceState {
    constructor() {
        this._type = "";
        this._data = null;
        this._typeAsEnum = DeviceResponseType.Unknown;
    }
    get Data() {
        return this._data;
    }
    set Data(value) {
        this._data = value;
    }
    get Type() {
        return this._type;
    }
    set Type(value) {
        this._type = value;
    }
    get TypeAsEnum() {
        return this._typeAsEnum;
    }
    set TypeAsEnum(value) {
        this._typeAsEnum = value;
    }
}
export var StateReliability;
(function (StateReliability) {
    StateReliability[StateReliability["Confident"] = 0] = "Confident";
    StateReliability[StateReliability["Unconfident"] = 1] = "Unconfident";
})(StateReliability || (StateReliability = {}));
export class ChannelOnOffDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.ChannelOnOffState;
        this.Type = nameof(ChannelOnOffState);
        this.Data = state.state;
    }
}
export class ChannelOnOffState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = ChannelOnOffStateEnum.Unknown;
        this.Time = "";
    }
}
export var ChannelOnOffStateEnum;
(function (ChannelOnOffStateEnum) {
    ChannelOnOffStateEnum[ChannelOnOffStateEnum["On"] = 0] = "On";
    ChannelOnOffStateEnum[ChannelOnOffStateEnum["Off"] = 1] = "Off";
    ChannelOnOffStateEnum[ChannelOnOffStateEnum["Unknown"] = 2] = "Unknown";
})(ChannelOnOffStateEnum || (ChannelOnOffStateEnum = {}));
export class DoorBellDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.DoorBellState;
        this.Type = nameof(DoorBellState);
        this.Data = state.state;
    }
}
export class DoorBellState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = DoorBellStateEnum.Relased;
        this.Time = "";
    }
}
export var DoorBellStateEnum;
(function (DoorBellStateEnum) {
    DoorBellStateEnum[DoorBellStateEnum["Pressed"] = 0] = "Pressed";
    DoorBellStateEnum[DoorBellStateEnum["Relased"] = 1] = "Relased";
    DoorBellStateEnum[DoorBellStateEnum["PressedAndRelased"] = 2] = "PressedAndRelased";
})(DoorBellStateEnum || (DoorBellStateEnum = {}));
export class ReedPositionDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.ReedPosition;
        this.Type = nameof(ReedPostionState);
        this.Data = state.state;
    }
}
export class ReedPostionState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = false;
        this.Time = "";
    }
}
export class BlindPositionDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.BlindPosition;
        this.Type = nameof(BlindPostionState);
        this.Data = state.state;
    }
}
export class BlindPostionState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Position = 0;
        this.RawPosition = 0;
        this.Time = "";
    }
}
export class RemoteButtonDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.RemoteButtonState;
        this.Type = nameof(RemoteButtonState);
        this.Data = state.state;
    }
}
export class RemoteButtonState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = RemoteButtonStateEnum.Relased;
        this.Time = "";
    }
}
export var RemoteButtonStateEnum;
(function (RemoteButtonStateEnum) {
    RemoteButtonStateEnum[RemoteButtonStateEnum["Pressed"] = 1] = "Pressed";
    RemoteButtonStateEnum[RemoteButtonStateEnum["Relased"] = 2] = "Relased";
    RemoteButtonStateEnum[RemoteButtonStateEnum["PressedAndRelased"] = 3] = "PressedAndRelased";
})(RemoteButtonStateEnum || (RemoteButtonStateEnum = {}));
export class LightColorDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.LightColor;
        this.Type = nameof(LightColorState);
        this.Data = state.state;
    }
}
export class LightColorState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.R = 0;
        this.G = 0;
        this.B = 0;
        this.Time = "";
    }
}
export class LightWarmthDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.LightWarmth;
        this.Type = nameof(LightWarmthState);
        this.Data = state.state;
    }
}
export class LightWarmthState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Temperature = 0;
        this.Time = "";
    }
}
export class LightBrightnessDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.LightBrightness;
        this.Type = nameof(LightBrightnessState);
        this.Data = state.state;
    }
}
export class LightBrightnessState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Brightness = 0;
        this.Time = "";
    }
}
export class MeasuredTemperatureDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.MeasuredTemperature;
        this.Type = nameof(MeasuredTemperatureState);
        this.Data = state.state;
    }
}
export class MeasuredTemperatureState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Temperature = 0;
        this.Type = MeasuredTemperatureTypeEnum.InsideTemperature;
        this.Time = "";
    }
}
var MeasuredTemperatureTypeEnum;
(function (MeasuredTemperatureTypeEnum) {
    MeasuredTemperatureTypeEnum[MeasuredTemperatureTypeEnum["AirTemperature"] = 0] = "AirTemperature";
    MeasuredTemperatureTypeEnum[MeasuredTemperatureTypeEnum["InsideTemperature"] = 1] = "InsideTemperature";
    MeasuredTemperatureTypeEnum[MeasuredTemperatureTypeEnum["OutsideTemperature"] = 2] = "OutsideTemperature";
    MeasuredTemperatureTypeEnum[MeasuredTemperatureTypeEnum["FloorTemperature"] = 3] = "FloorTemperature";
    MeasuredTemperatureTypeEnum[MeasuredTemperatureTypeEnum["SafetyTemperature"] = 4] = "SafetyTemperature";
    MeasuredTemperatureTypeEnum[MeasuredTemperatureTypeEnum["SetTemperature"] = 5] = "SetTemperature";
})(MeasuredTemperatureTypeEnum || (MeasuredTemperatureTypeEnum = {}));
export class BatteryDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.BatteryState;
        this.Type = nameof(BatteryState);
        this.Data = state.state;
    }
}
export class BatteryState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = BatteryStateEnum.Half;
        this.Percentage = -1;
        this.Time = "";
    }
}
export var BatteryStateEnum;
(function (BatteryStateEnum) {
    BatteryStateEnum[BatteryStateEnum["Full"] = 0] = "Full";
    BatteryStateEnum[BatteryStateEnum["Empty"] = 1] = "Empty";
    BatteryStateEnum[BatteryStateEnum["Half"] = 2] = "Half";
    BatteryStateEnum[BatteryStateEnum["Percentage"] = 3] = "Percentage";
    BatteryStateEnum[BatteryStateEnum["Low"] = 4] = "Low";
    BatteryStateEnum[BatteryStateEnum["ExternalPower"] = 5] = "ExternalPower";
})(BatteryStateEnum || (BatteryStateEnum = {}));
export class MeasuredBrightnessDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.MeasuredBrightness;
        this.Type = nameof(MeasuredBrightnessState);
        this.Data = state.state;
    }
}
export class MeasuredBrightnessState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Brightness = 0;
        this.Time = "";
    }
}
export class MeasuredEnergyDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.MeasuredEnergy;
        this.Type = nameof(MeasuredEnergyState);
        this.Data = state.state;
    }
}
export class MeasuredEnergyState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Voltage = 0;
        this.Current = 0;
        this.PhaseShift = 0;
        this.ActivePower = 0;
        this.ReactivePower = 0;
        this.ApparentPower = 0;
        this.PowerFactor = 0;
        this.ActiveEnergy = 0;
        this.ReactiveEnergy = 0;
        this.Frequency = 0;
        this.Time = "";
    }
}
export class MeasuredDistanceDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.MeasuredDistance;
        this.Type = nameof(MeasuredDistanceState);
        this.Data = state.state;
    }
}
export class MeasuredDistanceState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Distance = 0;
        this.DetectedObject = DetectedObjectStateEnum.No;
        this.Time = "";
    }
}
export var DetectedObjectStateEnum;
(function (DetectedObjectStateEnum) {
    DetectedObjectStateEnum[DetectedObjectStateEnum["No"] = 0] = "No";
    DetectedObjectStateEnum[DetectedObjectStateEnum["Yes"] = 1] = "Yes";
})(DetectedObjectStateEnum || (DetectedObjectStateEnum = {}));
export class MovementSensorDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.MovementSensorState;
        this.Type = nameof(MovementSensorState);
        this.Data = state.state;
    }
}
export class MovementSensorState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Intensity = 0;
        this.Movement = MovementStateEnum.No;
        this.Time = "";
    }
}
export var MovementStateEnum;
(function (MovementStateEnum) {
    MovementStateEnum[MovementStateEnum["No"] = 0] = "No";
    MovementStateEnum[MovementStateEnum["Yes"] = 1] = "Yes";
})(MovementStateEnum || (MovementStateEnum = {}));
export class BlindRemoteButtonDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.BlindRemoteButtonState;
        this.Type = nameof(BlindRemoteButtonState);
        this.Data = state.state;
    }
}
export class BlindRemoteButtonState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = BlindRemoteButtonStateEnum.StopReleased;
        this.Time = "";
    }
}
export var BlindRemoteButtonStateEnum;
(function (BlindRemoteButtonStateEnum) {
    BlindRemoteButtonStateEnum[BlindRemoteButtonStateEnum["OpenPressed"] = 1] = "OpenPressed";
    BlindRemoteButtonStateEnum[BlindRemoteButtonStateEnum["OpenReleased"] = 2] = "OpenReleased";
    BlindRemoteButtonStateEnum[BlindRemoteButtonStateEnum["StopPressed"] = 3] = "StopPressed";
    BlindRemoteButtonStateEnum[BlindRemoteButtonStateEnum["StopReleased"] = 4] = "StopReleased";
    BlindRemoteButtonStateEnum[BlindRemoteButtonStateEnum["ClosePressed"] = 5] = "ClosePressed";
    BlindRemoteButtonStateEnum[BlindRemoteButtonStateEnum["CloseReleased"] = 6] = "CloseReleased";
})(BlindRemoteButtonStateEnum || (BlindRemoteButtonStateEnum = {}));
export class FacadeRemoteButtonDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.FacadeRemoteButtonState;
        this.Type = nameof(FacadeRemoteButtonState);
        this.Data = state.state;
    }
}
export class FacadeRemoteButtonState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = FacadeRemoteButtonStateEnum.StopReleased;
        this.Time = "";
    }
}
export var FacadeRemoteButtonStateEnum;
(function (FacadeRemoteButtonStateEnum) {
    FacadeRemoteButtonStateEnum[FacadeRemoteButtonStateEnum["OpenPressed"] = 1] = "OpenPressed";
    FacadeRemoteButtonStateEnum[FacadeRemoteButtonStateEnum["OpenReleased"] = 2] = "OpenReleased";
    FacadeRemoteButtonStateEnum[FacadeRemoteButtonStateEnum["StopPressed"] = 3] = "StopPressed";
    FacadeRemoteButtonStateEnum[FacadeRemoteButtonStateEnum["StopReleased"] = 4] = "StopReleased";
    FacadeRemoteButtonStateEnum[FacadeRemoteButtonStateEnum["ClosePressed"] = 5] = "ClosePressed";
    FacadeRemoteButtonStateEnum[FacadeRemoteButtonStateEnum["CloseReleased"] = 6] = "CloseReleased";
})(FacadeRemoteButtonStateEnum || (FacadeRemoteButtonStateEnum = {}));
export class SignalStrenghtDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.SignalStrength;
        this.Type = nameof(SignalStrenghtState);
        this.Data = state.state;
    }
}
export class SignalStrenghtState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Quality = LinkQualityEnum.Unknown;
        this.MeasurementTime = "";
        this.DidLastTaskSucceded = false;
        this.Percentage = 0;
        this.SuccededExecutionsPercentage = 0;
        this.SuccededTransmissionsPercentage = 0;
        this.Time = "";
    }
}
export var LinkQualityEnum;
(function (LinkQualityEnum) {
    LinkQualityEnum[LinkQualityEnum["Unknown"] = 0] = "Unknown";
    LinkQualityEnum[LinkQualityEnum["Excellent"] = 1] = "Excellent";
    LinkQualityEnum[LinkQualityEnum["Good"] = 2] = "Good";
    LinkQualityEnum[LinkQualityEnum["Acceptable"] = 3] = "Acceptable";
    LinkQualityEnum[LinkQualityEnum["Low"] = 4] = "Low";
    LinkQualityEnum[LinkQualityEnum["Terrible"] = 5] = "Terrible";
    LinkQualityEnum[LinkQualityEnum["NoLink"] = 6] = "NoLink";
})(LinkQualityEnum || (LinkQualityEnum = {}));
export class GatePositionDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.GatePosition;
        this.Type = nameof(GatePositionState);
        this.Data = state.state;
    }
}
export class GatePositionState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.PositionType = GatePositionTypeEnum.Unknown;
        this.Position = 0;
        this.Time = "";
    }
}
export var GatePositionTypeEnum;
(function (GatePositionTypeEnum) {
    GatePositionTypeEnum[GatePositionTypeEnum["Unknown"] = 0] = "Unknown";
    GatePositionTypeEnum[GatePositionTypeEnum["Open"] = 1] = "Open";
    GatePositionTypeEnum[GatePositionTypeEnum["PartiallyOpen"] = 2] = "PartiallyOpen";
    GatePositionTypeEnum[GatePositionTypeEnum["Close"] = 3] = "Close";
    GatePositionTypeEnum[GatePositionTypeEnum["On"] = 4] = "On";
    GatePositionTypeEnum[GatePositionTypeEnum["Off"] = 5] = "Off";
})(GatePositionTypeEnum || (GatePositionTypeEnum = {}));
export class GatewayPositionDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.GatewayPosition;
        this.Type = nameof(GatewayPositionState);
        this.Data = state.state;
    }
}
export class GatewayPositionState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.PositionType = GatewayPositionTypeEnum.Unknown;
        this.Position = 0;
        this.Time = "";
    }
}
export var GatewayPositionTypeEnum;
(function (GatewayPositionTypeEnum) {
    GatewayPositionTypeEnum[GatewayPositionTypeEnum["Unknown"] = 0] = "Unknown";
    GatewayPositionTypeEnum[GatewayPositionTypeEnum["Open"] = 1] = "Open";
    GatewayPositionTypeEnum[GatewayPositionTypeEnum["PartiallyOpen"] = 2] = "PartiallyOpen";
    GatewayPositionTypeEnum[GatewayPositionTypeEnum["Close"] = 3] = "Close";
    GatewayPositionTypeEnum[GatewayPositionTypeEnum["On"] = 4] = "On";
    GatewayPositionTypeEnum[GatewayPositionTypeEnum["Off"] = 5] = "Off";
})(GatewayPositionTypeEnum || (GatewayPositionTypeEnum = {}));
export class BlindCalibrationDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.BlindCalibration;
        this.Type = nameof(BlindCalibrationState);
        this.Data = state.state;
    }
}
export class BlindCalibrationState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.CalibrationStatus = BlindCalibrationStatusEnum.AutoLernIdle;
        this.Time = "";
    }
}
export var BlindCalibrationStatusEnum;
(function (BlindCalibrationStatusEnum) {
    BlindCalibrationStatusEnum[BlindCalibrationStatusEnum["AutoLernIdle"] = 0] = "AutoLernIdle";
    BlindCalibrationStatusEnum[BlindCalibrationStatusEnum["AutoLernInProgress"] = 1] = "AutoLernInProgress";
    BlindCalibrationStatusEnum[BlindCalibrationStatusEnum["AutoLernSuccessfull"] = 2] = "AutoLernSuccessfull";
    BlindCalibrationStatusEnum[BlindCalibrationStatusEnum["AutoLernCancelled"] = 4] = "AutoLernCancelled";
})(BlindCalibrationStatusEnum || (BlindCalibrationStatusEnum = {}));
export class HumiditySensorDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.HumiditySensorState;
        this.Type = nameof(HumiditySensorState);
        this.Data = state.state;
    }
}
export class HumiditySensorState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Type = HumidityTypeEnum.AirHumidity;
        this.Humidity = 0;
        this.Time = "";
    }
}
export var HumidityTypeEnum;
(function (HumidityTypeEnum) {
    HumidityTypeEnum[HumidityTypeEnum["AirHumidity"] = 0] = "AirHumidity";
    HumidityTypeEnum[HumidityTypeEnum["InsideHumidity"] = 1] = "InsideHumidity";
    HumidityTypeEnum[HumidityTypeEnum["OutsideHumidity"] = 2] = "OutsideHumidity";
    HumidityTypeEnum[HumidityTypeEnum["SafetyHumidity"] = 3] = "SafetyHumidity";
    HumidityTypeEnum[HumidityTypeEnum["SetHumidity"] = 4] = "SetHumidity";
})(HumidityTypeEnum || (HumidityTypeEnum = {}));
export class VibrationSensorDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.VibrationSensorState;
        this.Type = nameof(VibrationSensorState);
        this.Data = state.state;
    }
}
export class VibrationSensorState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Vibration = VibrationTypeEnum.No;
        this.Acceleration_X = 0;
        this.Acceleration_Y = 0;
        this.Acceleration_Z = 0;
        this.AccelerationModule = 0;
        this.Time = "";
    }
}
export var VibrationTypeEnum;
(function (VibrationTypeEnum) {
    VibrationTypeEnum[VibrationTypeEnum["No"] = 0] = "No";
    VibrationTypeEnum[VibrationTypeEnum["Yes"] = 1] = "Yes";
})(VibrationTypeEnum || (VibrationTypeEnum = {}));
export class BinarySensorStateDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.BinarySensorState;
        this.Type = nameof(BinarySensorState);
        this.Data = state.state;
    }
}
export class BinarySensorState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.State = BinarySensorStateEnum.Low;
        this.Time = "";
    }
}
export var BinarySensorStateEnum;
(function (BinarySensorStateEnum) {
    BinarySensorStateEnum[BinarySensorStateEnum["High"] = 1] = "High";
    BinarySensorStateEnum[BinarySensorStateEnum["Low"] = 0] = "Low";
})(BinarySensorStateEnum || (BinarySensorStateEnum = {}));
export class ConfigurationDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.ConfigurationState;
        this.Type = nameof(ConfigurationState);
        this.Data = state.state;
    }
}
export class ConfigurationState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Configuration = ConfigurationStateEnum.Unknown;
        this.Time = "";
    }
}
export var ConfigurationStateEnum;
(function (ConfigurationStateEnum) {
    ConfigurationStateEnum[ConfigurationStateEnum["Unknown"] = 0] = "Unknown";
    ConfigurationStateEnum[ConfigurationStateEnum["OngoingConfiguration"] = 1] = "OngoingConfiguration";
    ConfigurationStateEnum[ConfigurationStateEnum["NotConfigured"] = 2] = "NotConfigured";
    ConfigurationStateEnum[ConfigurationStateEnum["Configured"] = 3] = "Configured";
    ConfigurationStateEnum[ConfigurationStateEnum["PartiallyConfigured"] = 4] = "PartiallyConfigured";
})(ConfigurationStateEnum || (ConfigurationStateEnum = {}));
export class BlindOpenCloseTimeDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.BlindOpenCloseTime;
        this.Type = nameof(BlindOpenCloseTimeState);
        this.Data = state.state;
    }
}
export class BlindOpenCloseTimeState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Vibration = VibrationTypeEnum.No;
        this.CloseTime = 0;
        this.OpenTime = 0;
        this.HallCounter = 0;
        this.Time = "";
    }
}
export class OvercurrentProtectionDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.OvercurrentProtectionState;
        this.Type = nameof(OvercurrentProtectionState);
        this.Data = state.state;
    }
}
export class OvercurrentProtectionState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Triggered = false;
        this.Time = "";
    }
}
export class OvercurrentProtectionThresholdDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.OvercurrentProtectionThreshold;
        this.Type = nameof(OvercurrentProtectionThresholdState);
        this.Data = state.state;
    }
}
export class OvercurrentProtectionThresholdState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Current = 0;
        this.Time = "";
    }
}
export class FacadePositionDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.FacadePosition;
        this.Type = nameof(FacadePositionState);
        this.Data = state.state;
    }
}
export class FacadePositionState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Position = 0;
        this.Tilt = 0;
        this.Time = "";
    }
}
export class CurrentWindThresholdDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.CurrentWindThreshold;
        this.Type = nameof(CurrentWindThresholdState);
        this.Data = state.state;
    }
}
export class CurrentWindThresholdState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.WindThreshold = WindThresholdStateEnum.Unknown;
        this.Time = "";
    }
}
export var WindThresholdStateEnum;
(function (WindThresholdStateEnum) {
    WindThresholdStateEnum[WindThresholdStateEnum["Unknown"] = 0] = "Unknown";
    WindThresholdStateEnum[WindThresholdStateEnum["Below"] = 1] = "Below";
    WindThresholdStateEnum[WindThresholdStateEnum["Exceeded"] = 2] = "Exceeded";
    WindThresholdStateEnum[WindThresholdStateEnum["Inactive"] = 3] = "Inactive";
})(WindThresholdStateEnum || (WindThresholdStateEnum = {}));
export class CurrentLightThresholdDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.CurrentWindThreshold;
        this.Type = nameof(CurrentLightThresholdState);
        this.Data = state.state;
    }
}
export class CurrentLightThresholdState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.LightThreshold = LightThresholdStateEnum.Unknown;
        this.Value = 0;
        this.Time = "";
    }
}
export var LightThresholdStateEnum;
(function (LightThresholdStateEnum) {
    LightThresholdStateEnum[LightThresholdStateEnum["Unknown"] = 0] = "Unknown";
    LightThresholdStateEnum[LightThresholdStateEnum["Below"] = 1] = "Below";
    LightThresholdStateEnum[LightThresholdStateEnum["Exceeded"] = 2] = "Exceeded";
})(LightThresholdStateEnum || (LightThresholdStateEnum = {}));
export class WindSpeedDeviceState extends DeviceState {
    constructor(state) {
        super();
        this.TypeAsEnum = DeviceResponseType.WindSpeedState;
        this.Type = nameof(WindSpeedState);
        this.Data = state.state;
    }
}
export class WindSpeedState {
    constructor() {
        this.Channel = 0;
        this.StateReliability = StateReliability.Unconfident;
        this.Value = 0;
        this.Time = "";
    }
}
//# sourceMappingURL=IDeviceState.js.map