import { nameof } from "ts-simple-nameof";
import { LogLevel } from "./ILoggerService";
export class LoggerService {
    constructor() {
        this._blockedServices = [];
        this._logLevel = LogLevel.Debug;
    }
    GetNameOf(service) {
        if (service != null && (typeof service === 'string' || service instanceof String))
            return `${service}`;
        else
            return nameof(service);
    }
    IsBlocked(service) {
        if (service === undefined)
            return false;
        let name = "";
        if (service != null) {
            if (typeof service === 'string' || service instanceof String)
                name = this.GetNameOf(`${service}`);
            else
                name = this.GetNameOf(service);
        }
        return this._blockedServices.any(a => a == name);
    }
    DisableLogsFrom(service) {
        let name = this.GetNameOf(service);
        if (this._blockedServices.all(a => a != name))
            this._blockedServices.push(name);
    }
    EnableLogsFrom(service) {
        let name = this.GetNameOf(service);
        if (this._blockedServices.any(a => a == name))
            this._blockedServices = this._blockedServices.where(a => a != name).toArray();
    }
    get LogLevel() {
        return this._logLevel;
    }
    set LogLevel(level) {
        this._logLevel = level;
    }
    GetServiceName() {
        return nameof(LoggerService);
    }
    GetTimeStamp() {
        const date = new Date();
        return `${date.getHours()}:${date.getMinutes()}:${date.getSeconds()}.${date.getMilliseconds()} | `;
    }
    Warning(contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Warning:
            case LogLevel.Info:
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.warn(`${this.GetTimeStamp()}[WARN] ${contextClassType}`);
            else
                console.warn(`${this.GetTimeStamp()}[WARN] [${contextClassType}] ${message}`);
        else if (contextClassType != null && contextClassType instanceof Object)
            console.warn(`${this.GetTimeStamp()}[WARN] [${nameof(contextClassType)}] ${message}`);
    }
    Error(contextClassType, message) {
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.error(`${this.GetTimeStamp()}[ERROR] ${contextClassType}`);
            else
                console.error(`${this.GetTimeStamp()}[ERROR] [${contextClassType}] ${message}`);
        else if (contextClassType != null && contextClassType instanceof Object)
            console.error(`${this.GetTimeStamp()}[ERROR] [${nameof(contextClassType)}] ${message}`);
    }
    Info(contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Info:
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.info(`${this.GetTimeStamp()}[INFO] ${contextClassType}`);
            else
                console.info(`${this.GetTimeStamp()}[INFO] [${contextClassType}] ${message}`);
        else if (contextClassType != null && contextClassType instanceof Object)
            console.info(`${this.GetTimeStamp()}[INFO] [${nameof(contextClassType)}] ${message}`);
    }
    Debug(contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.debug(`${this.GetTimeStamp()}[DEBUG] ${contextClassType}`);
            else
                console.debug(`${this.GetTimeStamp()}[DEBUG] [${contextClassType}] ${message}`);
        else if (contextClassType != null && contextClassType instanceof Object)
            console.debug(`${this.GetTimeStamp()}[DEBUG] [${nameof(contextClassType)}] ${message}`);
    }
    Log(contextClassType, message) {
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.log(`${this.GetTimeStamp()}[LOG] ${contextClassType}`);
            else
                console.log(`${this.GetTimeStamp()}[LOG] [${contextClassType}] ${message}`);
        else if (contextClassType != null && contextClassType instanceof Object)
            console.log(`${this.GetTimeStamp()}[LOG] [${nameof(contextClassType)}] ${message}`);
    }
}
//# sourceMappingURL=LoggerService.js.map